<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>CheckUpdate</name>
    <message>
        <source>Last check: </source>
        <translation>Dernière vérification :</translation>
    </message>
</context>
<context>
    <name>QuitTestingChannelDialog</name>
    <message>
        <source>If you exit the beta program, you will no longer receive beta updates.</source>
        <translation>Si vous quittez le programme bêta, vous ne recevrez plus les mises à jour bêta.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
</context>
<context>
    <name>UpdateControl</name>
    <message>
        <source>View Update Log</source>
        <translation>Afficher les journaux de mise à jour</translation>
    </message>
</context>
<context>
    <name>UpdateHistoryDialog</name>
    <message>
        <source>Update History</source>
        <translation>Historique des mises à jour</translation>
    </message>
    <message>
        <source>No update history</source>
        <translation>Aucun historique des mises à jour</translation>
    </message>
    <message>
        <source>System Updates</source>
        <translation>Mises à jour du système</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Mises à jour de sécurité</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and security updates</source>
        <translation>Fournit une mise à jour cumulative comprenant de nouvelles fonctionnalités, des mises à jour de qualité et des mises à jour de sécurité.</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Fournit des mises à jour de sécurité</translation>
    </message>
    <message>
        <source>Installation date:</source>
        <translation>Date d&apos;installation :</translation>
    </message>
</context>
<context>
    <name>UpdateList</name>
    <message>
        <source>View Details</source>
        <translation>Voir les détails</translation>
    </message>
    <message>
        <source>Release time:</source>
        <translation>Date de sortie :</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Réduire</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Version :</translation>
    </message>
</context>
<context>
    <name>UpdateLogDialog</name>
    <message>
        <source>Update Log</source>
        <translation>Journal des mises à jour</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Export to desktop</source>
        <translation>Exporter vers le bureau</translation>
    </message>
</context>
<context>
    <name>UpdateLogHelper</name>
    <message>
        <source>NONE</source>
        <translation>AUCUN</translation>
    </message>
    <message>
        <source>LOW</source>
        <translation>FAIBLE</translation>
    </message>
    <message>
        <source>MEDIUM</source>
        <translation>MOYEN</translation>
    </message>
    <message>
        <source>HIGH</source>
        <translation>ÉLEVÉ</translation>
    </message>
    <message>
        <source>CRITICAL</source>
        <translation>CRITIQUE</translation>
    </message>
    <message>
        <source>critical-risk</source>
        <translation>risque critique</translation>
    </message>
    <message>
        <source>high-risk</source>
        <translation>risque élevé</translation>
    </message>
    <message>
        <source>medium-risk</source>
        <translation>risque moyen</translation>
    </message>
    <message>
        <source>low-risk</source>
        <translation>faible risque</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>inconnu</translation>
    </message>
    <message>
        <source>This update fixes</source>
        <translation>Cette mise à jour corrige</translation>
    </message>
    <message>
        <source>vulnerabilities</source>
        <translation>vulnérabilités</translation>
    </message>
    <message>
        <source>vulnerability</source>
        <translation>vulnérabilité</translation>
    </message>
    <message>
        <source>%1 of %2 %3</source>
        <translation>%1 de %2 %3</translation>
        <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
    </message>
    <message>
        <source>, </source>
        <translation>, </translation>
        <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
    </message>
    <message>
        <source>for more details, please visit </source>
        <translation>Pour plus de détails, veuillez consulter</translation>
        <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Checking for updates, please wait…</source>
        <translation>Vérification des mises à jour, veuillez patienter...</translation>
    </message>
    <message>
        <source>Your system is up to date</source>
        <translation>Votre système est à jour</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Erreur inconnue</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please free up %1 disk space first.</source>
        <translation>Le téléchargement des mises à jour a échoué. Veuillez libérer %1 d&apos;espace disque au préalable.</translation>
    </message>
    <message>
        <source>Dependency error, failed to detect the updates</source>
        <translation>Erreur de dépendance, impossible de détecter les mises à jour</translation>
    </message>
    <message>
        <source>Please check your network and try again.</source>
        <translation>Veuillez vérifier votre connexion réseau et réessayer.</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please check your network and try again.</source>
        <translation>Échec du téléchargement des mises à jour. Veuillez vérifier votre connexion réseau et réessayer.</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Impossible d&apos;effectuer la sauvegarde du système. Si vous poursuivez les mises à jour, vous ne pourrez plus revenir à l&apos;ancien système ultérieurement.</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Si vous poursuivez les mises à jour, vous ne pourrez plus revenir à l&apos;ancien système par la suite.</translation>
    </message>
    <message>
        <source>Insufficient disk space</source>
        <translation>Espace disque insuffisant</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>Erreur DPKG</translation>
    </message>
    <message>
        <source>File missing</source>
        <translation>Fichier manquant</translation>
    </message>
    <message>
        <source>Service connection is abnormal, please check the network and try again</source>
        <translation>La connexion au service est anormale, veuillez vérifier le réseau et réessayer.</translation>
    </message>
    <message>
        <source>The repository source configuration is not valid, please check and try again.</source>
        <translation>La configuration de la source du référentiel n&apos;est pas valide, veuillez vérifier et réessayer.</translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation>Revérifier</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation>Politique de confidentialité</translation>
    </message>
    <message>
        <source>To use this software, you must accept the %1 that accompanies software updates.</source>
        <translation>Pour utiliser ce logiciel, vous devez accepter les %1 qui accompagnent les mises à jour logicielles.</translation>
    </message>
    <message>
        <source>Turn on the switches under Update Content to get better experiences</source>
        <translation>Activez les options sous &quot;Mettre à jour le contenu&quot; pour bénéficier d&apos;une meilleure expérience.</translation>
    </message>
    <message>
        <source>Your system is not activated, and it failed to connect to update services</source>
        <translation>Votre système n&apos;est pas activé et n&apos;a pas pu se connecter aux services de mise à jour.</translation>
    </message>
    <message>
        <source>The system updates are disabled. Please contact your administrator for help</source>
        <translation>Les mises à jour du système sont désactivées. Veuillez contacter votre administrateur pour obtenir de l&apos;aide.</translation>
    </message>
    <message>
        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
        <translation>Le système a activé la fonction de récupération automatique et ne prend pas en charge les mises à jour. Si vous avez des questions, veuillez contacter l&apos;administrateur de l&apos;entreprise.</translation>
    </message>
</context>
<context>
    <name>UpdateSelectDialog</name>
    <message>
        <source>The updates have been already downloaded. What do you want to do?</source>
        <translation>Les mises à jour ont déjà été téléchargées. Que souhaitez-vous faire ?</translation>
    </message>
    <message>
        <source>Silent Installation</source>
        <translation>Installation silencieuse</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Mettre à jour et redémarrer</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Mettre à jour et arrêter</translation>
    </message>
</context>
<context>
    <name>UpdateSetting</name>
    <message>
        <source>Smart Mirror Switch</source>
        <translation>Commutateur de miroir intelligent</translation>
    </message>
    <message>
        <source>Update Type</source>
        <translation>Type de mise à jour</translation>
    </message>
    <message>
        <source>Function Updates</source>
        <translation>Mises à jour des fonctionnalités</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
        <translation>Fournit une mise à jour cumulative comprenant de nouvelles fonctionnalités, des mises à jour de qualité et des mises à jour de sécurité.</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Mises à jour de sécurité</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>Fournit des mises à jour de sécurité</translation>
    </message>
    <message>
        <source>Third-party Updates</source>
        <translation>Mises à jour tierces</translation>
    </message>
    <message>
        <source>Delivers  updates for additional repository sources</source>
        <translation>Fournit des mises à jour pour des sources de référentiel supplémentaires.</translation>
    </message>
    <message>
        <source>Limit Speed</source>
        <translation>Vitesse maximale</translation>
    </message>
    <message>
        <source>Limit Setting</source>
        <translation>Paramétrage de limites</translation>
    </message>
    <message>
        <source>Auto Download</source>
        <translation>Téléchargement automatique</translation>
    </message>
    <message>
        <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
        <translation>Activer l&apos;option &quot;Téléchargement automatique des mises à jour&quot; permettra de télécharger automatiquement les mises à jour lorsque vous êtes connecté à Internet.</translation>
    </message>
    <message>
        <source>Download when Inactive</source>
        <translation>Télécharger lorsque inactif</translation>
    </message>
    <message>
        <source>Start at</source>
        <translation>Commencer à</translation>
    </message>
    <message>
        <source>End at</source>
        <translation>Terminer à</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>Paramètres avancés</translation>
    </message>
    <message>
        <source>Updates Notification</source>
        <translation>Notification des mises à jour</translation>
    </message>
    <message>
        <source>Clear Package Cache</source>
        <translation>Vider le cache des paquets</translation>
    </message>
    <message>
        <source>Update History</source>
        <translation>Historique des mises à jour</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Voir</translation>
    </message>
    <message>
        <source>Join Internal Testing Channel</source>
        <translation>Rejoindre le canal de test interne</translation>
    </message>
    <message>
        <source>Click here to complete the application</source>
        <translation>Cliquez ici pour compléter la demande.</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Développer</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Réduire</translation>
    </message>
    <message>
        <source>Only numbers between 1-99999 are allowed</source>
        <translation>Seuls les nombres compris entre 1-99999 sont autorisés.</translation>
    </message>
    <message>
        <source>Join the internal testing channel to get deepin latest updates.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>System Updates</source>
        <translation>Mises à jour du système</translation>
    </message>
    <message>
        <source>Fixed some known bugs and security vulnerabilities</source>
        <translation>Correction de quelques bugs connus et vulnérabilités de sécurité</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>Mises à jour de sécurité</translation>
    </message>
    <message>
        <source>Third-party Repositories</source>
        <translation>Référentiels tiers</translation>
    </message>
    <message>
        <source>updatelog</source>
        <translation>journal des mises à jour</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>L&apos;exportation du journal a échoué, veuillez réessayer.</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>Le journal a été exporté vers le bureau.</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Mettre à jour</translation>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation>Veuillez brancher l&apos;appareil, puis installer les mises à jour.</translation>
    </message>
</context>
<context>
    <name>update</name>
    <message>
        <source>System Update</source>
        <translation>Mises à jour du système</translation>
    </message>
    <message>
        <source>System update and upgrade</source>
        <translation>Mise à jour et mise à niveau du système</translation>
    </message>
</context>
<context>
    <name>updateMain</name>
    <message>
        <source>Update Settings</source>
        <translation>Paramètres des mises à jour</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>Installation</translation>
    </message>
    <message>
        <source>Update download completed</source>
        <translation>Téléchargement de la mise à jour terminé</translation>
    </message>
    <message>
        <source>Install updates</source>
        <translation>Installer les mises à jour</translation>
    </message>
    <message>
        <source>Update size: </source>
        <translation>Taille de la mise à jour :</translation>
    </message>
    <message>
        <source>Update download failed</source>
        <translation>Échec du téléchargement de la mise à jour</translation>
    </message>
    <message>
        <source>Downloading updates...</source>
        <translation>Téléchargement des mises à jour...</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Téléchargement</translation>
    </message>
    <message>
        <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
        <translation>Configurer les paramètres de mise à jour, les mises à jour de sécurité, le téléchargement automatique des mises à jour et les notifications de mise à jour.</translation>
    </message>
    <message>
        <source>Reboot now</source>
        <translation>Redémarrer maintenant</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Télécharger</translation>
    </message>
    <message>
        <source>Installing updates...</source>
        <translation>Installation des mises à jour...</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Réessayer</translation>
    </message>
    <message>
        <source>Continue Update</source>
        <translation>Continuer la mise à jour</translation>
    </message>
    <message>
        <source>Updates Available</source>
        <translation>Mises à jour disponibles</translation>
    </message>
    <message>
        <source>Installation update failed</source>
        <translation>Échec de l&apos;installation de la mise à jour</translation>
    </message>
    <message>
        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
        <translation>Pour garantir le bon fonctionnement de votre système et de vos applications, veuillez redémarrer votre ordinateur après la mise à jour.</translation>
    </message>
    <message>
        <source>Backing up in progress...</source>
        <translation>Sauvegarde en cours...</translation>
    </message>
    <message>
        <source>Backing up in progress</source>
        <translation>Sauvegarde en cours</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>Échec de la sauvegarde</translation>
    </message>
    <message>
        <source>Update installation successful</source>
        <translation>Mise à jour installée avec succès</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>Si vous poursuivez les mises à jour, vous ne pourrez plus revenir à l&apos;ancien système par la suite.</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Réessayer</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>Procéder à la mise à jour</translation>
    </message>
    <message>
        <source>The battery capacity is lower than 60%. To get successful updates, please plug in.</source>
        <translation>La capacité de la batterie est inférieure à 60 %. Pour que la mise à jour s&apos;effectue correctement, veuillez brancher l&apos;appareil.</translation>
    </message>
</context>
</TS>